pub enum ConceptPredicate {
Active(bool),
DefinitionStatus {
defined: bool,
primitive: bool,
},
Module {
modules: Vec<u64>,
negated: bool,
},
EffectiveTime {
operator: Comparison,
values: Vec<u32>,
},
}Expand description
One concept filter with its concept sets resolved, for the model.
Variants
Active(bool)
The concept is active (or, false, inactive).
DefinitionStatus
The definition status is one of the allowed ones.
Module
The module is one of modules (SCTIDs), or is not when negated.
EffectiveTime
The effective time compares to one of values (YYYYMMDD; != means
to none of them).