pub enum DescriptionPredicate {
Term {
operator: Equality,
terms: Vec<TypedSearchTerm>,
},
Language {
operator: Equality,
codes: Vec<String>,
},
Type {
operator: Equality,
types: Vec<u64>,
},
Dialect {
operator: Equality,
dialects: Vec<(u64, Vec<Acceptability>)>,
},
Active(bool),
Id {
operator: Equality,
ids: Vec<u64>,
},
}Expand description
One description filter with its concept sets and aliases resolved, for
the model; every predicate of one {{ D ... }} must hold for the same
description.
Variants
Term
The term matches one of the search terms (or, !=, none).
Language
The language code (the primary subtag) is one of codes.
Type
The description type is one of types (SCTIDs).
Dialect
The description is acceptable in one of the language reference sets, with one of the listed acceptabilities when any are listed.
Fields

dialects: Vec<(u64, Vec<Acceptability>)>(language reference set SCTID, allowed acceptabilities).
Active(bool)
The description is active (or, false, inactive).
Id
The description identifier is one of ids.