Kind

Enum Kind 

pub enum Kind {
Show 36 variants Term, String, AltIdentifier, Integer, Identifier, ChildOrSelfOf, DescendantOrSelfOf, ChildOf, LessOrEqual, LessThan, ParentOrSelfOf, AncestorOrSelfOf, ParentOf, GreaterOrEqual, GreaterThan, Top, Bottom, NotEqual, Equal, LeftParen, RightParen, DoubleLeftBrace, DoubleRightBrace, LeftBrace, RightBrace, LeftBracket, RightBracket, Colon, Comma, Caret, To, Period, Asterisk, Hash, Plus, Dash,
}
A token kind.

Variants



Term

|term| (eclconceptreference, altidentifier).



String

A quoted string (typedsearchterm, timevalue, the quoted altidentifier, and the string concrete value).



AltIdentifier

scheme#code (altidentifier without quotes).



Integer

A run of digits (sctid, integervalue, nonnegativeintegervalue).



Identifier

A word: the keywords, refsetfieldname, languagecode, dialectalias, and the reverse flag R.



ChildOrSelfOf

<<!



DescendantOrSelfOf

<<



ChildOf

<!



LessOrEqual

<=



LessThan

<



ParentOrSelfOf

>>!



AncestorOrSelfOf

>>



ParentOf

>!



GreaterOrEqual

>=



GreaterThan

>



Top

!!>



Bottom

!!<



NotEqual

!=



Equal

=



LeftParen

(



RightParen

)



DoubleLeftBrace

{{



DoubleRightBrace

}}



LeftBrace

{



RightBrace

}



LeftBracket

[



RightBracket

]



Colon

:



Comma

,



Caret

^



To

..



Period

.



Asterisk

*



Hash

#



Plus

+



Dash

-

Implementations

Source

impl Kind

pub const fn describe(self) -> &'static str

The token class as an error message names it.